@@ -5,7 +5,7 @@ use base qw( Data::Phrasebook::Loader::Base Data::Phrasebook::Debug );
 use Carp qw( croak );
 use YAML;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -24,16 +24,12 @@ Data::Phrasebook::Loader::YAML - Absract your phrases with YAML.
     $q->delimiters( qr{ \[% \s* (\w+) \s* %\] }x );
     my $phrase = $q->fetch($keyword);
 
-=head1 ABSTRACT
-
-This module provides a loader class for phrasebook implementations using YAML.
-
 =head1 DESCRIPTION
 
-This class loader implements phrasebook patterns using YAML. 
+This class loader implements phrasebook patterns using YAML.
 
-Phrases can be contained within one or more dictionaries, with each phrase 
-accessible via a unique key. Phrases may contain placeholders, please see 
+Phrases can be contained within one or more dictionaries, with each phrase
+accessible via a unique key. Phrases may contain placeholders, please see
 L<Data::Phrasebook> for an explanation of how to use these. Groups of phrases
 are kept in a dictionary. In this implementation a single file is one
 complete dictionary.
@@ -45,7 +41,7 @@ An example YAML file:
     Welcome to [% my %] world.
     It is a nice [%place %].
 
-Within the phrase text placeholders can be used, which are then replaced with 
+Within the phrase text placeholders can be used, which are then replaced with
 the appropriate values once the get() method is called. The default style of
 placeholders can be altered using the delimiters() method.
 
@@ -263,7 +259,7 @@ C<0000default>); it need not contain any keys.
 
 =head1 SEE ALSO
 
-L<Data::Phrasebook>, 
+L<Data::Phrasebook>,
 L<Data::Phrasebook::Loader>.
 
 =head1 BUGS, PATCHES & FIXES
@@ -271,20 +267,12 @@ L<Data::Phrasebook::Loader>.
 There are no known bugs at the time of this release. However, if you spot a
 bug or are experiencing difficulties, that is not explained within the POD
 documentation, please send an email to barbie@cpan.org or submit a bug to the
-RT system (http://rt.cpan.org/). However, it would help greatly if you are 
-able to pinpoint problems or even supply a patch. 
+RT system (http://rt.cpan.org/). However, it would help greatly if you are
+able to pinpoint problems or even supply a patch.
 
-Fixes are dependant upon their severity and my availablity. Should a fix not
+Fixes are dependent upon their severity and my availability. Should a fix not
 be forthcoming, please feel free to (politely) remind me.
 
-=head1 DSLIP
-
-  b - Beta testing
-  d - Developer
-  p - Perl-only
-  O - Object oriented
-  p - Standard-Perl: user may choose between GPL and Artistic
-
 =head1 AUTHOR
 
   Original author: Iain Campbell Truskett (16.07.1979 - 29.12.2003)
@@ -293,15 +281,10 @@ be forthcoming, please feel free to (politely) remind me.
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2003 Iain Truskett. All rights reserved.
-  Copyright (C) 2004-2007 Barbie for Miss Barbell Productions.
-  All Rights Reserved.
+  Copyright (C) 2003 Iain Truskett.
+  Copyright (C) 2004-2012 Barbie for Miss Barbell Productions.
 
-  This library is free software; you can redistribute it and/or modify
-  it under the same terms as Perl itself.
-
-The full text of the licenses can be found in the F<Artistic> and
-F<COPYING> files included with this module, or in L<perlartistic> and
-L<perlgpl> in Perl 5.8.1 or later.
+  This module is free software; you can redistribute it and/or
+  modify it under the Artistic License 2.0.
 
 =cut
